<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xg="http://www.xgewerbe.de/spezifikation/0.1-pilot"
                xmlns:xoev-code="http://xoev.de/schemata/code/1_0"
                xmlns:xoev-lc="http://xoev.de/latinchars/1_1/datatypes"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <!--PHASES-->
   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <!--XSD TYPES FOR XSLT2-->
   <!--KEYS AND FUNCTIONS-->
   <!--DEFAULT RULES-->
   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path-2"/>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>
   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>
   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <svrl:ns-prefix-in-attribute-values uri="http://www.xgewerbe.de/spezifikation/0.1-pilot" prefix="xg"/>
         <svrl:ns-prefix-in-attribute-values uri="http://xoev.de/schemata/code/1_0" prefix="xoev-code"/>
         <svrl:ns-prefix-in-attribute-values uri="http://xoev.de/latinchars/1_1/datatypes" prefix="xoev-lc"/>
         <xsl:apply-templates select="/" mode="M3"/>
      </svrl:schematron-output>
   </xsl:template>
   <!--SCHEMATRON PATTERNS-->
   <!--PATTERN -->
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung"
                 priority="1170"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)">
               <xsl:attribute name="id">SCH-GWA-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden. Bei einem Reisegewerbe darf keine Niederlassungsart angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)">
               <xsl:attribute name="id">SCH-GWA-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Betriebsstätte angegeben werden. Bei einem Reisegewerbe darf keine Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)">
               <xsl:attribute name="id">SCH-GWA-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Sofern eine Zweigniederlassung oder eine unselbstständige Zweigstelle angezeigt wird, ist die davon abweichende Hauptniederlassung ebenfalls anzugeben. Ansonsten ist die Angabe einer abweichenden Hauptniederlassung nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung"
                 priority="1169"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)">
               <xsl:attribute name="id">SCH-GWA-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden. Bei einem Reisegewerbe darf keine Niederlassungsart angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)">
               <xsl:attribute name="id">SCH-GWA-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Betriebsstätte angegeben werden. Bei einem Reisegewerbe darf keine Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if&#xA;(xg:grundAnmeldungSchluessel/code = '01' and&#xA;(xg:niederlassungArt/code = '1' or&#xA;xg:abweichendeHauptniederlassung/xg:anschrift/&#xA;xg:nationSchluessel ne '276' or xs:boolean(xg:istReisegewerbe))) then empty(xg:bisherigeUnfallversicherung) else exists(xg:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:grundAnmeldungSchluessel/code = '01' and (xg:niederlassungArt/code = '1' or xg:abweichendeHauptniederlassung/xg:anschrift/ xg:nationSchluessel ne '276' or xs:boolean(xg:istReisegewerbe))) then empty(xg:bisherigeUnfallversicherung) else exists(xg:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-GWA-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>In der Gewerbeanmeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen. Ausgenommen hiervon sind Neugründungen für Hauptniederlassungen und Neugründungen für Zweigniederlassungen oder unselbständige Zweigstellen, deren Hauptniederlassung sich im Ausland befindet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xs:boolean(xg:istReisegewerbe)) then xs:boolean(xg:betriebArt/xg:handwerk) or xs:boolean(xg:betriebArt/xg:handel) or xs:boolean(xg:betriebArt/xg:sonstiges) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xs:boolean(xg:istReisegewerbe)) then xs:boolean(xg:betriebArt/xg:handwerk) or xs:boolean(xg:betriebArt/xg:handel) or xs:boolean(xg:betriebArt/xg:sonstiges) else true()">
               <xsl:attribute name="id">SCH-GWA-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:grundAnmeldungSchluessel/code = '05') then exists(//xg:referenziertesSubjekt/xg:*/xg:istBeteiligtAn.id) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:grundAnmeldungSchluessel/code = '05') then exists(//xg:referenziertesSubjekt/xg:*/xg:istBeteiligtAn.id) else true()">
               <xsl:attribute name="id">SCH-GWA-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:grundAnmeldungSchluessel/code = '06') then exists(xg:frueheresGewerbe/*) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:grundAnmeldungSchluessel/code = '06') then exists(xg:frueheresGewerbe/*) else true()">
               <xsl:attribute name="id">SCH-GWA-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer Übernahme (Erbfolge/Verkauf/ Verpachtung) ist das frühere Gewerbe anzugeben. Ggf. ist 'unbekannt' einzutragen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:grundAnmeldungSchluessel/code = '03') then exists(xg:frueheresGewerbe/*) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:grundAnmeldungSchluessel/code = '03') then exists(xg:frueheresGewerbe/*) else true()">
               <xsl:attribute name="id">SCH-GWA-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einem Übergang nach dem Umwandlungsgesetz (z. B. Verschmelzung, Spaltung) ist das frühere Gewerbe anzugeben. Ggf. ist 'unbekannt' einzutragen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(//xg:referenziertesSubjekt/xg:*[xg:id = current()/xg:gewerbetreibender.id and xg:rechtsform/code = ('170', '180', '270')] and xg:beteiligungOeffentlicheHand/code = '1')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(//xg:referenziertesSubjekt/xg:*[xg:id = current()/xg:gewerbetreibender.id and xg:rechtsform/code = ('170', '180', '270')] and xg:beteiligungOeffentlicheHand/code = '1')">
               <xsl:attribute name="id">SCH-GWA-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Beteiligung der öffentlichen Hand kann für Einzelunternehmen und GbRs nicht vorliegen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)">
               <xsl:attribute name="id">SCH-GWA-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Sofern eine Zweigniederlassung oder eine unselbstständige Zweigstelle angezeigt wird, ist die davon abweichende Hauptniederlassung ebenfalls anzugeben. Ansonsten ist die Angabe einer abweichenden Hauptniederlassung nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung"
                 priority="1168"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:niederlassungArt) else empty(xg:niederlassungArt)">
               <xsl:attribute name="id">SCH-GWA-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden. Bei einem Reisegewerbe darf keine Niederlassungsart angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (not(xs:boolean(xg:istReisegewerbe))) then exists(xg:betriebsstaette) else empty(xg:betriebsstaette)">
               <xsl:attribute name="id">SCH-GWA-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn das Gewerbe kein Reisegewerbe ist, muss die Betriebsstätte angegeben werden. Bei einem Reisegewerbe darf keine Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:niederlassungArt/code = ('2','3')) then exists (xg:abweichendeHauptniederlassung) else empty(xg:abweichendeHauptniederlassung)">
               <xsl:attribute name="id">SCH-GWA-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Sofern eine Zweigniederlassung oder eine unselbstständige Zweigstelle angezeigt wird, ist die davon abweichende Hauptniederlassung ebenfalls anzugeben. Ansonsten ist die Angabe einer abweichenden Hauptniederlassung nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerkskarte"
                 priority="1167"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xs:boolean(preceding-sibling::xg:betriebArt/xg:handwerk) = true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xs:boolean(preceding-sibling::xg:betriebArt/xg:handwerk) = true()">
               <xsl:attribute name="id">SCH-GWA-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gewerbetreibender.id"
                 priority="1166"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]">
               <xsl:attribute name="id">SCH-GWA-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gewerbetreibende muss eine natürliche oder eine juristische Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)">
               <xsl:attribute name="id">SCH-GWA-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für den Gewerbetreibenden muss eine Rechtsform angegeben sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-GWA-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn der Gewerbetreibende eine natürliche Person ist, sind für diese Angaben zu Geburtsdatum, Geburtsort inklusive Staat, Anschrift, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gewerbetreibender.id"
                 priority="1165"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]">
               <xsl:attribute name="id">SCH-GWA-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gewerbetreibende muss eine natürliche oder eine juristische Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)">
               <xsl:attribute name="id">SCH-GWA-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für den Gewerbetreibenden muss eine Rechtsform angegeben sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-GWA-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn der Gewerbetreibende eine natürliche Person ist, sind für diese Angaben zu Geburtsdatum, Geburtsort inklusive Staat, Anschrift, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gewerbetreibender.id"
                 priority="1164"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/(xg:natuerlichePerson|xg:juristischePerson)[xg:id = current()]">
               <xsl:attribute name="id">SCH-GWA-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gewerbetreibende muss eine natürliche oder eine juristische Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)">
               <xsl:attribute name="id">SCH-GWA-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für den Gewerbetreibenden muss eine Rechtsform angegeben sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:geburtsort and $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-GWA-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn der Gewerbetreibende eine natürliche Person ist, sind für diese Angaben zu Geburtsdatum, Geburtsort inklusive Staat, Anschrift, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:vertretungsberechtigtePersonOderBetriebsleiter.id"
                 priority="1163"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')">
               <xsl:attribute name="id">SCH-GWA-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Angaben zur vertretungsberechtigtenPerson / zum Betriebsleiter sind nur Angaben zum Namen zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test=" //xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')">
               <xsl:attribute name="id">SCH-GWA-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Die Angabe einer vertretungsberechtigten Person oder eines Betriebsleiters (im Sinne von Formularfeld 14) ist nur bei inländischen Aktiengesellschaften, Zweigniederlassungen oder unselbstständigen Zweigstellen zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:vertretungsberechtigtePersonOderBetriebsleiter.id"
                 priority="1162"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')">
               <xsl:attribute name="id">SCH-GWA-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Angaben zur vertretungsberechtigtenPerson / zum Betriebsleiter sind nur Angaben zum Namen zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test=" //xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')">
               <xsl:attribute name="id">SCH-GWA-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Die Angabe einer vertretungsberechtigten Person oder eines Betriebsleiters (im Sinne von Formularfeld 14) ist nur bei inländischen Aktiengesellschaften, Zweigniederlassungen oder unselbstständigen Zweigstellen zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:vertretungsberechtigtePersonOderBetriebsleiter.id"
                 priority="1161"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $e in //xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]/*/local-name() satisfies $e = ('vorname', 'familienname', 'id')">
               <xsl:attribute name="id">SCH-GWA-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Angaben zur vertretungsberechtigtenPerson / zum Betriebsleiter sind nur Angaben zum Namen zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test=" //xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:juristischePerson[xg:id = current()/../xg:gewerbetreibender.id]/xg:rechtsform/code = ('310','320','321','322','324','360') or ../xg:niederlassungArt/code = ('2','3')">
               <xsl:attribute name="id">SCH-GWA-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Die Angabe einer vertretungsberechtigten Person oder eines Betriebsleiters (im Sinne von Formularfeld 14) ist nur bei inländischen Aktiengesellschaften, Zweigniederlassungen oder unselbstständigen Zweigstellen zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:ursacheAbmeldungSchluessel"
                 priority="1160"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:ursacheAbmeldungSchluessel/code = ('13', '19', '20', '21', '22'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:ursacheAbmeldungSchluessel/code = ('13', '19', '20', '21', '22'))">
               <xsl:attribute name="id">SCH-GWA-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Die Abmeldung von Amts wegen ist als Angabe bei UrsacheAbmeldung nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerkskarte"
                 priority="1159"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xs:boolean(preceding-sibling::xg:betriebArt/xg:handwerk) = true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xs:boolean(preceding-sibling::xg:betriebArt/xg:handwerk) = true()">
               <xsl:attribute name="id">SCH-GWA-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:betriebsleiter.id"
                 priority="1158"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="exists(//xg:natuerlichePerson[xg:id = current()])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//xg:natuerlichePerson[xg:id = current()])">
               <xsl:attribute name="id">SCH-HW-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Betriebsleiter muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit and xg:handwerk.eintragungsvoraussetzung]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit and xg:handwerk.eintragungsvoraussetzung]">
               <xsl:attribute name="id">SCH-HW-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen Betriebsleiter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht, Staatsangehörigkeit und Eintragungsvoraussetzungen erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:betriebsinhaber.id"
                 priority="1157"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//xg:referenziertesSubjekt/xg:*[xg:id = current()]/xg:rechtsform)">
               <xsl:attribute name="id">SCH-HW-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für den Betriebsinhaber muss eine Rechtsform angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-HW-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn der Betriebsinhaber eine natürliche Person ist, sind für diese Angaben zu Anschrift, Geschlecht, Geburtsdatum und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:aufenthaltstitel"
                 priority="1156"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext des Antrags auf Eintragung eines Handwerks sind keine Angaben zu Aufenthaltstiteln zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext Handwerk sind keine Angaben zum Aufenthaltstitel zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:aufenthaltstitel"
                 priority="1155"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext des Antrags auf Eintragung eines Handwerks sind keine Angaben zu Aufenthaltstiteln zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext Handwerk sind keine Angaben zum Aufenthaltstitel zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:aufenthaltstitel"
                 priority="1154"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext des Antrags auf Eintragung eines Handwerks sind keine Angaben zu Aufenthaltstiteln zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext Handwerk sind keine Angaben zum Aufenthaltstitel zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:aufenthaltstitel"
                 priority="1153"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext des Antrags auf Eintragung eines Handwerks sind keine Angaben zu Aufenthaltstiteln zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext Handwerk sind keine Angaben zum Aufenthaltstitel zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:aufenthaltstitel"
                 priority="1152"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext des Antrags auf Eintragung eines Handwerks sind keine Angaben zu Aufenthaltstiteln zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(ancestor::xg:handwerk.handwerkseintragung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(ancestor::xg:handwerk.handwerkseintragung)">
               <xsl:attribute name="id">SCH-HW-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Im Kontext Handwerk sind keine Angaben zum Aufenthaltstitel zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:betriebsstaette"
                 priority="1151"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xs:boolean(following-sibling::xg:istHauptbetrieb) = true()) then xg:erreichbarkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xs:boolean(following-sibling::xg:istHauptbetrieb) = true()) then xg:erreichbarkeit else true()">
               <xsl:attribute name="id">SCH-HW-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für den Hauptbetrieb muss eine Erreichbarkeit angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:weitereBetriebsstaette"
                 priority="1150"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xs:boolean(preceding-sibling::xg:istHauptbetrieb) = true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xs:boolean(preceding-sibling::xg:istHauptbetrieb) = true()">
               <xsl:attribute name="id">SCH-HW-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Element weitereBetriebsstaette ist nur zulässig, wenn die Eintragung eines Hauptbetriebs beantragt wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung" priority="1149" mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xs:boolean(xg:istHauptbetrieb) = false()) then xg:abweichenderHauptbetrieb else empty(xg:abweichenderHauptbetrieb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xs:boolean(xg:istHauptbetrieb) = false()) then xg:abweichenderHauptbetrieb else empty(xg:abweichenderHauptbetrieb)">
               <xsl:attribute name="id">SCH-HW-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die anzumeldende Betriebsstätte kein Hauptbetrieb ist, sind Angaben zum abweichenden Hauptbetrieb erforderlich. Andernfalls ist das Element abweichenderHauptbetrieb nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:juristischePerson"
                 priority="1148"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')">
               <xsl:attribute name="id">SCH-KERN-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine juristische Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:natuerlichePerson"
                 priority="1147"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')">
               <xsl:attribute name="id">SCH-KERN-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine natürliche Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:geburtsort) then xg:geburtsland else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:geburtsort) then xg:geburtsland else true()">
               <xsl:attribute name="id">SCH-KERN-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn Angaben zum Geburtsort gemacht werden, ist die Angabe des Geburtslands erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:personengesellschaft"
                 priority="1146"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')">
               <xsl:attribute name="id">SCH-KERN-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Personengesellschaft erfordert die Angabe einer entsprechenden Rechtsform</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)">
               <xsl:attribute name="id">SCH-KERN-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform GbR sind die Namen der weiteren Gesellschafter anzugeben (Das Element gbrGeselschafter ist für diese und nur für diese Rechtsform anzugeben).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:juristischePerson"
                 priority="1145"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')">
               <xsl:attribute name="id">SCH-KERN-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine juristische Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:natuerlichePerson"
                 priority="1144"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')">
               <xsl:attribute name="id">SCH-KERN-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine natürliche Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:geburtsort) then xg:geburtsland else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:geburtsort) then xg:geburtsland else true()">
               <xsl:attribute name="id">SCH-KERN-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn Angaben zum Geburtsort gemacht werden, ist die Angabe des Geburtslands erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:personengesellschaft"
                 priority="1143"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')">
               <xsl:attribute name="id">SCH-KERN-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Personengesellschaft erfordert die Angabe einer entsprechenden Rechtsform</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)">
               <xsl:attribute name="id">SCH-KERN-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform GbR sind die Namen der weiteren Gesellschafter anzugeben (Das Element gbrGeselschafter ist für diese und nur für diese Rechtsform anzugeben).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:juristischePerson"
                 priority="1142"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')">
               <xsl:attribute name="id">SCH-KERN-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine juristische Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:natuerlichePerson"
                 priority="1141"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')">
               <xsl:attribute name="id">SCH-KERN-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine natürliche Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:geburtsort) then xg:geburtsland else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:geburtsort) then xg:geburtsland else true()">
               <xsl:attribute name="id">SCH-KERN-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn Angaben zum Geburtsort gemacht werden, ist die Angabe des Geburtslands erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:personengesellschaft"
                 priority="1140"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')">
               <xsl:attribute name="id">SCH-KERN-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Personengesellschaft erfordert die Angabe einer entsprechenden Rechtsform</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)">
               <xsl:attribute name="id">SCH-KERN-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform GbR sind die Namen der weiteren Gesellschafter anzugeben (Das Element gbrGeselschafter ist für diese und nur für diese Rechtsform anzugeben).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:juristischePerson"
                 priority="1139"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')">
               <xsl:attribute name="id">SCH-KERN-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine juristische Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:natuerlichePerson"
                 priority="1138"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')">
               <xsl:attribute name="id">SCH-KERN-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine natürliche Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:geburtsort) then xg:geburtsland else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:geburtsort) then xg:geburtsland else true()">
               <xsl:attribute name="id">SCH-KERN-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn Angaben zum Geburtsort gemacht werden, ist die Angabe des Geburtslands erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:personengesellschaft"
                 priority="1137"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')">
               <xsl:attribute name="id">SCH-KERN-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Personengesellschaft erfordert die Angabe einer entsprechenden Rechtsform</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)">
               <xsl:attribute name="id">SCH-KERN-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform GbR sind die Namen der weiteren Gesellschafter anzugeben (Das Element gbrGeselschafter ist für diese und nur für diese Rechtsform anzugeben).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:juristischePerson"
                 priority="1136"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('310', '320', '321', '322', '323', '324', '350', '351', '360', '400', '450', '510', '590', '611', '700', '790', '911', '912', '992')">
               <xsl:attribute name="id">SCH-KERN-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine juristische Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:natuerlichePerson"
                 priority="1135"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xg:rechtsform) or xg:rechtsform/code = ('170', '180','921','991')">
               <xsl:attribute name="id">SCH-KERN-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine natürliche Person erfordert die Angabe einer entsprechenden Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:geburtsort) then xg:geburtsland else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:geburtsort) then xg:geburtsland else true()">
               <xsl:attribute name="id">SCH-KERN-00016</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn Angaben zum Geburtsort gemacht werden, ist die Angabe des Geburtslands erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:personengesellschaft"
                 priority="1134"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(xg:registereintrag and empty(xg:rechtsform))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xg:registereintrag and empty(xg:rechtsform))">
               <xsl:attribute name="id">SCH-KERN-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ein Registereintrag erfordert die Angabe einer Rechtsform.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:rechtsform/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '355', '356', '610', '921', '991')">
               <xsl:attribute name="id">SCH-KERN-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Personengesellschaft erfordert die Angabe einer entsprechenden Rechtsform</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then xg:gbRGesellschafter else empty(xg:gbRGesellschafter)">
               <xsl:attribute name="id">SCH-KERN-00018</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform GbR sind die Namen der weiteren Gesellschafter anzugeben (Das Element gbrGeselschafter ist für diese und nur für diese Rechtsform anzugeben).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '170') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF170</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 170 - eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '180') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF180</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 180 - nicht eingetragenes Einzelunternehmen - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '210') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF210</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 210 - Offene Handelsgesellschaft (OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '211') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF211</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 211 - Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '220') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF220</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 220 - Kommanditgesellschaft (KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '221') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF221</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 221 - Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '222') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF222</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 222 - eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '223') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF223</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 223 - Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '230') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF230</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 230 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '231') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF231</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 231 - Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '232') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF232</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 232 - Unternehmergesellschaft (haftungsbeschränkt) Co.KG auch UG (haftungsbeschränkt) &amp; Co.KG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '240') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF240</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 240 - Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '241') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF241</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 241 - Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '242') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 242 - Unternehmergesellschaft (haftungsbeschränkt) Co.OHG auch UG (haftungsbeschränkt) &amp;Co.OHG - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '250') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF250</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 250 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '251') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF251</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 251 - Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '260') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF260</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 260 - Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '270') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF270</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 270 - Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '280') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF280</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 280 - Europäische Wirtschaftliche Interessenvereinigung (EWIV) - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '290') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF290</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 290 - Sonstige nicht aufgeführte deutsche Personengesellschaft - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '310') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF310</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 310 - Aktiengesellschaften (AG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '320') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF320</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 320 - Kommanditgesellschaft auf Aktien (KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '321') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF321</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 321 - Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '322') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF322</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 322 - Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '323') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF323</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 323 - UG (haftungsbeschränkt) &amp; Co.KGaA - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '324') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 324 - Europäische Aktiengesellschaft und Co. Kommanditgesellschaft auf Aktien (SE &amp; Co. KGaA) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '350') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF350</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 350 - Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '351') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF351</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 351 - Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '355') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF355</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 355 - Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.) - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '356') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF356</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 356 - Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G. - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '360') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF360</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 360 - Europäische Aktiengesellschaft (SE) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '400') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF400</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 400 - eingetragene Genossenschaft (eG) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '450') then xg:registereintrag/xg:eintragungArt/code = ('G') else true()">
               <xsl:attribute name="id">SCH-KERN-RF450</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 450 - Europäische Genossenschaft (SCE) - ist ein Registereintrag anzugeben mit der Eintragungsart G.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '510') then xg:registereintrag/xg:eintragungArt/code = ('B') else true()">
               <xsl:attribute name="id">SCH-KERN-RF510</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 510 - Versicherungsverein auf Gegenseitigkeit (VVaG) - ist ein Registereintrag anzugeben mit der Eintragungsart B.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '590') then xg:registereintrag/xg:eintragungArt/code = ('V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF590</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 590 - eingetragener Verein - ist ein Registereintrag anzugeben mit der Eintragungsart V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '610') then empty(xg:registereintrag) else true()">
               <xsl:attribute name="id">SCH-KERN-RF610</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 610 - Nicht rechtsfähiger Verein - darf kein Registereintrag angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '611') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('S') else true()">
               <xsl:attribute name="id">SCH-KERN-RF611</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 611 - rechtsfähige Stiftung - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit der Eintragungsart S.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '700') then xg:registereintrag/xg:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-KERN-RF700</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 700 - Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten A, B, G, V.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '790') then xg:registereintrag/xg:eintragungArt/code = ('A') else true()">
               <xsl:attribute name="id">SCH-KERN-RF790</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 790 - Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts - ist ein Registereintrag anzugeben mit der Eintragungsart A.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '911') then xg:registereintrag/xg:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF911</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 911 - Private Company Limited by Shares (Ltd) - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '912') then xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF912</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 912 - Sonstige ausländische Rechtsform nach EU-Recht - juristische Person - ist ein Registereintrag anzugeben mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '921') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 921 - ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '991') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('A', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF991</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 991 - Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten A, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:rechtsform/code = '992') then empty(xg:registereintrag) or xg:registereintrag/xg:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-KERN-RF992</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für die Rechtsform 992 - Sonstige ausländische Rechtsform - juristische Person - ist entweder kein Registereintrag anzugeben oder ein Registereintrag mit einer der Eintragungsarten B, G, V, X.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:gesetzlicherVertreter.id"
                 priority="1133"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]">
               <xsl:attribute name="id">SCH-KERN-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der gesetzliche Vertreter einer juristischen Person muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]">
               <xsl:attribute name="id">SCH-KERN-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen gesetzlichen Vertreter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gesetzlicherVertreter.id"
                 priority="1132"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]">
               <xsl:attribute name="id">SCH-KERN-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der gesetzliche Vertreter einer juristischen Person muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]">
               <xsl:attribute name="id">SCH-KERN-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen gesetzlichen Vertreter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gesetzlicherVertreter.id"
                 priority="1131"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]">
               <xsl:attribute name="id">SCH-KERN-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der gesetzliche Vertreter einer juristischen Person muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]">
               <xsl:attribute name="id">SCH-KERN-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen gesetzlichen Vertreter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gesetzlicherVertreter.id"
                 priority="1130"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]">
               <xsl:attribute name="id">SCH-KERN-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der gesetzliche Vertreter einer juristischen Person muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]">
               <xsl:attribute name="id">SCH-KERN-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen gesetzlichen Vertreter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:gesetzlicherVertreter.id"
                 priority="1129"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:referenziertesSubjekt/xg:natuerlichePerson[xg:id = current()]">
               <xsl:attribute name="id">SCH-KERN-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der gesetzliche Vertreter einer juristischen Person muss eine natürliche Person sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="//xg:natuerlichePerson[xg:id = current() and xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit]">
               <xsl:attribute name="id">SCH-KERN-00014</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für einen gesetzlichen Vertreter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:registereintrag"
                 priority="1128"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then&#xA;exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-KERN-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-KERN-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:registereintrag"
                 priority="1127"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then&#xA;exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-KERN-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-KERN-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:registereintrag"
                 priority="1126"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then&#xA;exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-KERN-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-KERN-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:registereintrag"
                 priority="1125"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then&#xA;exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-KERN-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-KERN-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:registereintrag"
                 priority="1124"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then&#xA;exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xg:gerichtSchluessel) else empty(xg:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-KERN-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:eintragungArt/code = ('S', 'X')) then exists(xg:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-KERN-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:kanal"
                 priority="1123"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-KERN-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:kanal"
                 priority="1122"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-KERN-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:kanal"
                 priority="1121"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-KERN-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:kanal"
                 priority="1120"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-KERN-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:kanal"
                 priority="1119"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-KERN-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:hauptniederlassung//xg:erreichbarkeit"
                 priority="1118"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:nachrichtenkopf//xg:erreichbarkeit"
                 priority="1117"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:referenziertesSubjekt//xg:erreichbarkeit"
                 priority="1116"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:weitereBetriebsstaette//xg:erreichbarkeit"
                 priority="1115"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:abweichendeHauptniederlassung//xg:erreichbarkeit"
                 priority="1114"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:betriebsstaette//xg:erreichbarkeit"
                 priority="1113"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:kuenftigesGewerbe//xg:erreichbarkeit"
                 priority="1112"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:nachrichtenkopf//xg:erreichbarkeit"
                 priority="1111"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:referenziertesSubjekt//xg:erreichbarkeit"
                 priority="1110"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:abweichendeHauptniederlassung//xg:erreichbarkeit"
                 priority="1109"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:betriebsstaette//xg:erreichbarkeit"
                 priority="1108"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:frueheresGewerbe//xg:erreichbarkeit"
                 priority="1107"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:nachrichtenkopf//xg:erreichbarkeit"
                 priority="1106"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:referenziertesSubjekt//xg:erreichbarkeit"
                 priority="1105"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:abweichendeHauptniederlassung//xg:erreichbarkeit"
                 priority="1104"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:betriebsstaette//xg:erreichbarkeit"
                 priority="1103"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:frueheresGewerbe//xg:erreichbarkeit"
                 priority="1102"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:nachrichtenkopf//xg:erreichbarkeit"
                 priority="1101"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:referenziertesSubjekt//xg:erreichbarkeit"
                 priority="1100"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:abweichenderHauptbetrieb//xg:erreichbarkeit"
                 priority="1099"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:betriebsstaette//xg:erreichbarkeit"
                 priority="1098"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:nachrichtenkopf//xg:erreichbarkeit"
                 priority="1097"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:referenziertesSubjekt//xg:erreichbarkeit"
                 priority="1096"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:weitereBetriebsstaette//xg:erreichbarkeit"
                 priority="1095"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:kanal/code = ('02','03','04')) then starts-with(xg:kennung,'0') or starts-with(xg:kennung,'+') else true()">
               <xsl:attribute name="id">SCH-KERN-00010</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Eine Telefonnummer muss eine Vorwahl beinhalten (mit "0" oder "+" beginnen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:identifikation.nachricht"
                 priority="1094"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)">
               <xsl:attribute name="id">SCH-KERN-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der kodierte Nachrichtentyp muss dem XML-Dokumenttyp entsprechen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:identifikation.nachricht"
                 priority="1093"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)">
               <xsl:attribute name="id">SCH-KERN-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der kodierte Nachrichtentyp muss dem XML-Dokumenttyp entsprechen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:identifikation.nachricht"
                 priority="1092"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)">
               <xsl:attribute name="id">SCH-KERN-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der kodierte Nachrichtentyp muss dem XML-Dokumenttyp entsprechen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:identifikation.nachricht"
                 priority="1091"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)">
               <xsl:attribute name="id">SCH-KERN-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der kodierte Nachrichtentyp muss dem XML-Dokumenttyp entsprechen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:identifikation.nachricht"
                 priority="1090"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xg:nachrichtentyp/code = local-name(parent::xg:*/parent::xg:*)">
               <xsl:attribute name="id">SCH-KERN-00011</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Der kodierte Nachrichtentyp muss dem XML-Dokumenttyp entsprechen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:istBeteiligtAn.id"
                 priority="1089"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="current() = //xg:personengesellschaft/xg:id"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="current() = //xg:personengesellschaft/xg:id">
               <xsl:attribute name="id">SCH-KERN-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>istBeteiligtAn.id darf sich nur auf Personengesellschaften beziehen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()">
               <xsl:attribute name="id">SCH-KERN-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für eine natürliche Person als geschäftsführenden Gesellschafter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:istBeteiligtAn.id"
                 priority="1088"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="current() = //xg:personengesellschaft/xg:id"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="current() = //xg:personengesellschaft/xg:id">
               <xsl:attribute name="id">SCH-KERN-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>istBeteiligtAn.id darf sich nur auf Personengesellschaften beziehen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()">
               <xsl:attribute name="id">SCH-KERN-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für eine natürliche Person als geschäftsführenden Gesellschafter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:istBeteiligtAn.id"
                 priority="1087"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="current() = //xg:personengesellschaft/xg:id"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="current() = //xg:personengesellschaft/xg:id">
               <xsl:attribute name="id">SCH-KERN-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>istBeteiligtAn.id darf sich nur auf Personengesellschaften beziehen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()">
               <xsl:attribute name="id">SCH-KERN-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für eine natürliche Person als geschäftsführenden Gesellschafter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:istBeteiligtAn.id"
                 priority="1086"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="current() = //xg:personengesellschaft/xg:id"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="current() = //xg:personengesellschaft/xg:id">
               <xsl:attribute name="id">SCH-KERN-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>istBeteiligtAn.id darf sich nur auf Personengesellschaften beziehen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()">
               <xsl:attribute name="id">SCH-KERN-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für eine natürliche Person als geschäftsführenden Gesellschafter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:istBeteiligtAn.id"
                 priority="1085"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="current() = //xg:personengesellschaft/xg:id"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="current() = //xg:personengesellschaft/xg:id">
               <xsl:attribute name="id">SCH-KERN-00012</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>istBeteiligtAn.id darf sich nur auf Personengesellschaften beziehen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (parent::xg:natuerlichePerson) then xg:anschrift and xg:geschlecht and xg:geburtsdatum and xg:staatsangehoerigkeit else true()">
               <xsl:attribute name="id">SCH-KERN-00015</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Für eine natürliche Person als geschäftsführenden Gesellschafter sind Angaben zu Anschrift, Geburtsdatum, Geschlecht und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:antragsteller.id"
                 priority="1084"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-KERN-00013</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Falls der Antragsteller eine natürliche Person ist, sind für diesen Angaben zu Geburtsdatum, Geschlecht, Anschrift und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:antragsteller.id"
                 priority="1083"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-KERN-00013</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Falls der Antragsteller eine natürliche Person ist, sind für diesen Angaben zu Geburtsdatum, Geschlecht, Anschrift und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:antragsteller.id"
                 priority="1082"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-KERN-00013</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Falls der Antragsteller eine natürliche Person ist, sind für diesen Angaben zu Geburtsdatum, Geschlecht, Anschrift und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:antragsteller.id"
                 priority="1081"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-KERN-00013</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Falls der Antragsteller eine natürliche Person ist, sind für diesen Angaben zu Geburtsdatum, Geschlecht, Anschrift und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:antragsteller.id"
                 priority="1080"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $p in //xg:natuerlichePerson[xg:id = current()] satisfies $p/xg:anschrift and $p/xg:geschlecht and $p/xg:geburtsdatum and $p/xg:staatsangehoerigkeit">
               <xsl:attribute name="id">SCH-KERN-00013</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Falls der Antragsteller eine natürliche Person ist, sind für diesen Angaben zu Geburtsdatum, Geschlecht, Anschrift und Staatsangehörigkeit erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:handwerk.postanschrift"
                 priority="1079"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)">
               <xsl:attribute name="id">SCH-KERN-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei der Angabe eines Postempfängers ist entweder eine Angabe zur Anschrift oder eine Postanschrift erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:handwerk.postanschrift"
                 priority="1078"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)">
               <xsl:attribute name="id">SCH-KERN-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei der Angabe eines Postempfängers ist entweder eine Angabe zur Anschrift oder eine Postanschrift erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerk.postanschrift"
                 priority="1077"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)">
               <xsl:attribute name="id">SCH-KERN-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei der Angabe eines Postempfängers ist entweder eine Angabe zur Anschrift oder eine Postanschrift erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerk.postanschrift"
                 priority="1076"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)">
               <xsl:attribute name="id">SCH-KERN-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei der Angabe eines Postempfängers ist entweder eine Angabe zur Anschrift oder eine Postanschrift erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:handwerk.postanschrift"
                 priority="1075"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:anschrift) then empty(xg:postanschrift) else (xg:postanschrift)">
               <xsl:attribute name="id">SCH-KERN-00017</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei der Angabe eines Postempfängers ist entweder eine Angabe zur Anschrift oder eine Postanschrift erforderlich.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00001</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:geschaeftsanschrift"
                 priority="1074"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:hauptniederlassung/xg:anschrift"
                 priority="1073"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:hauptniederlassung/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1072"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:anschrift"
                 priority="1071"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:gewOErlaubnis.fruehererHauptwohnsitz//xg:anschrift"
                 priority="1070"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:weitereBetriebsstaette/xg:anschrift"
                 priority="1069"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag/xg:weitereBetriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1068"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:abweichendeHauptniederlassung/xg:anschrift"
                 priority="1067"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:abweichendeHauptniederlassung/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1066"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:betriebsstaette/xg:anschrift"
                 priority="1065"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:betriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1064"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:kuenftigesGewerbe//xg:anschrift"
                 priority="1063"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:anschrift"
                 priority="1062"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:gewOErlaubnis.fruehererHauptwohnsitz//xg:anschrift"
                 priority="1061"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:abweichendeHauptniederlassung/xg:anschrift"
                 priority="1060"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:abweichendeHauptniederlassung/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1059"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:betriebsstaette/xg:anschrift"
                 priority="1058"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:betriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1057"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:frueheresGewerbe//xg:anschrift"
                 priority="1056"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:anschrift"
                 priority="1055"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:gewOErlaubnis.fruehererHauptwohnsitz//xg:anschrift"
                 priority="1054"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:abweichendeHauptniederlassung/xg:anschrift"
                 priority="1053"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:abweichendeHauptniederlassung/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1052"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:betriebsstaette/xg:anschrift"
                 priority="1051"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:betriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1050"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:frueheresGewerbe//xg:anschrift"
                 priority="1049"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:anschrift"
                 priority="1048"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:gewOErlaubnis.fruehererHauptwohnsitz//xg:anschrift"
                 priority="1047"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:abweichenderHauptbetrieb/xg:anschrift"
                 priority="1046"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:abweichenderHauptbetrieb/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1045"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:betriebsstaette/xg:anschrift"
                 priority="1044"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:betriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1043"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:adresseVorherigerBetrieb"
                 priority="1042"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:fruehererSitz"
                 priority="1041"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:anschrift"
                 priority="1040"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:referenziertesSubjekt/xg:natuerlichePerson/xg:gewOErlaubnis.fruehererHauptwohnsitz//xg:anschrift"
                 priority="1039"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:weitereBetriebsstaette/xg:anschrift"
                 priority="1038"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung/xg:weitereBetriebsstaette/xg:handwerk.postanschrift//xg:anschrift"
                 priority="1037"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="if (xg:nationSchluessel = '276') then exists(xg:plz)&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xg:nationSchluessel = '276') then exists(xg:plz) else true()">
               <xsl:attribute name="id">SCH-KERN-00201</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:handwerk.eintragungsvoraussetzung"
                 priority="1036"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:handwerk.eintragungsvoraussetzung"
                 priority="1035"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerk.eintragungsvoraussetzung"
                 priority="1034"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerk.eintragungsvoraussetzung"
                 priority="1033"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:handwerk.eintragungsvoraussetzung"
                 priority="1032"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00002</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:handwerk.ihkMitgliedschaft"
                 priority="1031"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:handwerk.ihkMitgliedschaft"
                 priority="1030"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerk.ihkMitgliedschaft"
                 priority="1029"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerk.ihkMitgliedschaft"
                 priority="1028"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:handwerk.ihkMitgliedschaft"
                 priority="1027"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00003</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:handwerk.einordnungHandwerksberufe.zulassungspflichtig"
                 priority="1026"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerk.einordnungHandwerksberufe.zulassungspflichtig"
                 priority="1025"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerk.einordnungHandwerksberufe.zulassungspflichtig"
                 priority="1024"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:handwerk.einordnungHandwerksberufe.zulassungspflichtig"
                 priority="1023"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00004</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:handwerk.einordnungHandwerksberufe.nichtzulassungspflichtig"
                 priority="1022"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:handwerk.einordnungHandwerksberufe.nichtzulassungspflichtig"
                 priority="1021"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:handwerk.einordnungHandwerksberufe.nichtzulassungspflichtig"
                 priority="1020"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:handwerk.einordnungHandwerksberufe.nichtzulassungspflichtig"
                 priority="1019"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:handwerk.handwerkseintragung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:handwerk.handwerkseintragung">
               <xsl:attribute name="id">SCH-TEMP-00005</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Handwerk zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:gewerbeanzeige.anzahlGesetzlicheVertreter"
                 priority="1018"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gewerbeanzeige.anzahlGesetzlicheVertreter"
                 priority="1017"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gewerbeanzeige.anzahlGesetzlicheVertreter"
                 priority="1016"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gewerbeanzeige.anzahlGesetzlicheVertreter"
                 priority="1015"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:gewerbeanzeige.anzahlGesetzlicheVertreter"
                 priority="1014"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00006</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:gewerbeanzeige.erlaubnis"
                 priority="1013"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gewerbeanzeige.erlaubnis"
                 priority="1012"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gewerbeanzeige.erlaubnis"
                 priority="1011"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gewerbeanzeige.erlaubnis"
                 priority="1010"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:gewerbeanzeige.erlaubnis"
                 priority="1009"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00007</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewOErlaubnis.erlaubnisantrag//xg:gewerbeanzeige.anzahlGeschaeftsfuehrendeGesellschafter"
                 priority="1008"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gewerbeanzeige.anzahlGeschaeftsfuehrendeGesellschafter"
                 priority="1007"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gewerbeanzeige.anzahlGeschaeftsfuehrendeGesellschafter"
                 priority="1006"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gewerbeanzeige.anzahlGeschaeftsfuehrendeGesellschafter"
                 priority="1005"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:gewerbeanzeige.anzahlGeschaeftsfuehrendeGesellschafter"
                 priority="1004"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00008</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeabmeldung//xg:gewerbeanzeige.schwerpunkt"
                 priority="1003"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeanmeldung//xg:gewerbeanzeige.schwerpunkt"
                 priority="1002"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:gewerbeanzeige.gewerbeummeldung//xg:gewerbeanzeige.schwerpunkt"
                 priority="1001"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xg:handwerk.handwerkseintragung//xg:gewerbeanzeige.schwerpunkt"
                 priority="1000"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="ancestor::xg:gewerbeanzeige.gewerbeanmeldung or ancestor::xg:gewerbeanzeige.gewerbeummeldung or ancestor::xg:gewerbeanzeige.gewerbeabmeldung">
               <xsl:attribute name="id">SCH-TEMP-00009</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Ergänzung zum Kerndatenmodell - nur im Kontext Gewerbeanzeige zulässig</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
</xsl:stylesheet>
